# BEGIN COPYRIGHT BLOCK
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; version 2 of the License.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc.,
# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
#
# (C) 2007 Red Hat, Inc.
# All rights reserved.
# END COPYRIGHT BLOCK

###############################################################################
###                          D E F I N I T I O N S                          ###
###############################################################################

## Product Definitions
%define base_product      Operating System Utilities JNI Package
%define base_component    osutil

## Package Header Definitions
%define base_name         %{base_component}
%define base_version      1.2.0
%define base_release      4
%define base_phase        %{nil}
%define base_group        System Environment/Libraries
%define base_vendor       Red Hat, Inc.
%define base_license      GPLv2 with exceptions
%define base_packager     %{base_vendor} <http://bugzilla.redhat.com/bugzilla>
%define base_summary      %{base_product}
%define base_url          http://www.redhat.com/certificate_system

## Helper Definitions
%define pki_jdk           java-devel >= 1:1.6.0
# Override the default 'pki_jdk' on Fedora 8 platforms
%{?fc8:%define pki_jdk    java-devel >= 1.7.0}

## Build Definitions
%define base_build_dir    blds
%define base_staging_dir  STAGING

## Installation Definitions
%define base_install_dir  /opt/%{base_component}
%define setup_package     setup_package

## Don't build the debug packages
%define debug_package     %{nil}


##===================##
## Linux Definitions ##
##===================##
%ifos Linux
## 32-bit Definitions
%ifarch i386 i486 i586 i686
%define ant_cmd           ant -Dspecfile=%{base_name}.spec
%define architecture      intel
%define configure_cmd     ../configure
%endif

## 64-bit Definitions
%ifarch x86_64
%define ant_cmd           ant -Dspecfile=%{base_name}.spec
%define architecture      intel
%define configure_cmd     ../configure --enable-64bit --libdir=%{base_install_dir}/lib64
%endif

## A distribution model is required on certain Linux operating systems!
##
## check for a pre-defined distribution model
%define undefined_distro  %(test "%{dist}" = "" && echo 1 || echo 0)
%if %{undefined_distro}
%define is_fedora         %(test -e /etc/fedora-release && echo 1 || echo 0)
%if %{is_fedora}
## define a default distribution model on Fedora Linux
%define dist_prefix       .fc
%define dist_version      %(echo `rpm -qf --qf='%{VERSION}' /etc/fedora-release` | tr -d [A-Za-z])
%define dist              %{dist_prefix}%{dist_version}
%else
%define is_redhat         %(test -e /etc/redhat-release && echo 1 || echo 0)
%if %{is_redhat}
## define a default distribution model on Red Hat Linux
%define dist_prefix       .el
%define dist_version      %(echo `rpm -qf --qf='%{VERSION}' /etc/redhat-release` | tr -d [A-Za-z])
%define dist              %{dist_prefix}%{dist_version}
%endif
%endif
%endif
%endif



###############################################################################
###                       P A C K A G E   H E A D E R                       ###
###############################################################################

Name:           %{base_name}
Version:        %{base_version}
Release:        %{base_release}%{?base_phase}%{?dist}
Summary:        %{base_summary}
Vendor:         %{base_vendor}
URL:            %{base_url}
License:        %{base_license}
Packager:       %{base_packager}
Group:          %{base_group}


## Without AutoReqProv: no, rpmbuild finds all sorts of crazy
## dependencies that we don't care about, and refuses to install
AutoReqProv:    no

BuildRoot:      %{_builddir}/%{name}-root


## NOTE:  This spec file may require a specific JDK, "gcc", and/or "gcc-c++"
##        packages as well as the "rpm" and "rpm-build" packages.
##
##        Technically, "ant" should not need to be in "BuildRequires" since
##        it is the Java equivalent of "make" (and/or "Autotools").
##
BuildRequires:  ant >= 1.6.5, bash >= 3.2, %{pki_jdk}, jpackage-utils >= 1.7.3, nspr-devel >= 4.8.6, nss-devel >= 3.12.8, pkgconfig

## Without Requires something, rpmbuild will abort!
Requires:       jpackage-utils >= 1.7.3, nss >= 3.12.8


## This package is non-relocatable!
#Prefix:

Source0:        %{base_name}-%{base_version}.tar.gz

## This package currently contains no patches!
#Patch0:


%description
The Operating System Utilities Java Native Interface (JNI) package
supplies various native operating system operations to Java programs.



###############################################################################
###                  P R E P A R A T I O N   &   S E T U P                  ###
###############################################################################

## On Linux systems, prep and setup expect there to be a Source file
## in the /usr/src/redhat/SOURCES directory - it will be unpacked
## in the _builddir (not BuildRoot)
%prep


%setup -q -n %{base_name}-%{base_version}


## This package currently contains no patches!
#%patch0
# patches



###############################################################################
###                        B U I L D   P R O C E S S                        ###
###############################################################################

%build
%{?pkg_config_cmd}
%{ant_cmd}
mkdir %{base_build_dir}
cd %{base_build_dir}
mkdir %{base_staging_dir}
%{configure_cmd}
make



###############################################################################
###                 I N S T A L L A T I O N   P R O C E S S                 ###
###############################################################################

%install
%{?pkg_config_cmd}
rm -rf ${RPM_BUILD_ROOT}
cd %{base_build_dir}
make install DESTDIR="`pwd`/%{base_staging_dir}"

## rearrange files to be in the desired native packaging layout
../%{setup_package} ${RPM_BUILD_ROOT} %{version} %{base_release} %{architecture} `pwd`/%{base_staging_dir}/%{base_install_dir}

## add EULA to the appropriate native packaging location
cp -p ../EULA ${RPM_BUILD_ROOT}%{_datadir}/doc/%{base_name}-%{base_version}/
chmod 00644 ${RPM_BUILD_ROOT}%{_datadir}/doc/%{base_name}-%{base_version}/EULA



###############################################################################
###                      C L E A N U P   P R O C E S S                      ###
###############################################################################

%clean
rm -rf ${RPM_BUILD_ROOT}



###############################################################################
###  P R E  &  P O S T   I N S T A L L / U N I N S T A L L   S C R I P T S  ###
###############################################################################

## This package currently contains no pre-installation process!
#%pre


## This package currently contains no post-installation process!
#%post


## This package currently contains no pre-uninstallation process!
#%preun


## This package currently contains no post-uninstallation process!
#%postun



###############################################################################
###   I N V E N T O R Y   O F   F I L E S   A N D   D I R E C T O R I E S   ### 
###############################################################################

%files
%attr(-,root,root)     %{_jnidir}/*
%attr(-,root,root)     %{_libdir}/lib*
%attr(-,root,root)     %{_datadir}/doc/%{base_name}-%{base_version}/*



###############################################################################
###                            C H A N G E L O G                            ###
###############################################################################

%changelog
* Mon May  4 2015 Matthew Harmsen <mharmsen@redhat.com> 1.2.0-4
- Bump release number to build for RHCS 8.1.6

* Fri May  1 2015 Matthew Harmsen <mharmsen@redhat.com> 1.2.0-3
- Bump release number to build for RHCS 8.1.6

* Thu Mar 24 2011 Matthew Harmsen <mharmsen@redhat.com> 1.2.0-2
- Bugzilla Bug #690646 - Update Build and Runtime Dependencies for RHCS 8.1

* Tue Jan 12 2010 Matthew Harmsen <mharmsen@redhat.com> 1.2.0-1
- Bump to version 1.2.0

* Thu Jul 16 2009 Matthew Harmsen <mharmsen@redhat.com> 1.1.0-30
- Bugzilla Bug #512134 -  strip symbols from libraries, modules,
  and executables
- Release Candidate 4a build

* Mon Jul 13 2009 Matthew Harmsen <mharmsen@redhat.com> 1.1.0-29
- Bugzilla Bug #511136 -  Integrate EULA file into RHCS
- Release Candidate 4 build

* Wed Jul 8 2009 Kevin Wright <kwright@redhat.com> 1.1.0-28
- Bugzilla Bug #510387 - dist is not getting defined properly

* Wed Jul 8 2009 Kevin Wright <kwright@redhat.com> 1.1.0-27
- Bugzilla Bug #510352 -  Release Candidate 3 build

* Mon Jul 6 2009 Matthew Harmsen <mharmsen@redhat.com> 1.1.0-26
- bugzilla Bug #509183 -  update nss dependency >= 3.12.3.99

* Thu Jul 2 2009 Kevin Wright <kwright@redhat.com> 1.1.0-25
- Bugzilla Bug #509447 -  Release Candidate 2 build

* Thu Jun 25 2009 Kevin Wright <kwright@redhat.com> 1.1.0-24
- Bugzilla Bug #508179 -  Remove base_phase ".beta" tag

* Mon May 4 2009 Kevin Wright <kwright@redhat.com> 1.1.0-23
- Bugzilla Bug #499030 -  Beta 2 Release

* Fri Mar 27 2009 Matthew Harmsen <mharmsen@redhat.com> 1.1.0-22
- Bugzilla Bug #492502 -  Redefine "base_phase" from ".alpha" to ".beta"

* Sat Feb 28 2009 Matthew Harmsen <mharmsen@redhat.com> 1.1.0-21
- Bugzilla Bug #487896 - Introduce optional 'base_phase' release tag to
  denote ".alpha", ".beta", etc.

* Thu Feb 12 2009 Matthew Harmsen <mharmsen@redhat.com> 1.1.0-20
- Bugzilla Bug #483699 -  problem with the epoch in the spec file causes
  build to fail

* Mon Feb 2 2009 Matthew Harmsen <mharmsen@redhat.com> 1.1.0-19
- Bugzilla Bug #483695 - unable to build osutil in brew

* Thu Dec 4 2008 Matthew Harmsen <mharmsen@redhat.com> 1.1.0-18
- Bugzilla Bug #474369 - Remove NSS dependency on "pkcs11-devel" and
                         upgrade NSS/NSPR version dependencies  

* Sat Nov 29 2008 Matthew Harmsen <mharmsen@redhat.com> 1.1.0-17
- Aligned RHEL 5, RHEL 4, and Solaris 9 "base_release" numbers
- Bugzilla Bug #445402 - Changed "base_url" from
                         "http://www.redhat.com/software/rha/certificate" to
                         "http://www.redhat.com/certificate_system"

* Sat Nov 22 2008 Matthew Harmsen <mharmsen@redhat.com> 1.1.0-16
- Bugzilla Bug #472305 - "equality" tests in all spec files need to be fixed
- Bumped "java" and "java-devel" 1.4.2 and 1.5.0 dependencies to 1.6.0
- Changed "java-sdk" to "java-devel" for consistency

* Thu May 03 2007 Kevin McCarthy <kmccarth@redhat.com> 1.1.0-15
- Fix to work with RHEL5

* Tue Apr 10 2007 Matthew Harmsen <mharmsen@redhat.com> 1.1.0-14
- Revised LICENSE file.
- Bumped Release Number.

* Thu Apr 5 2007 Matthew Harmsen <mharmsen@redhat.com> 1.1.0-13
- Updated LICENSE file.
- Bumped Release Number.

* Tue Mar 27 2007 Matthew Harmsen <mharmsen@redhat.com> 1.1.0-12
- Made package URL contingent upon distribution.
- Bumped release number.

* Thu Mar 15 2007 Matthew Harmsen <mharmsen@redhat.com> 1.1.0-11
- Added NSS (devel) packages to "BuildRequires" and NSS to "Requires".
- Bumped release number.

* Thu Mar 15 2007 Matthew Harmsen <mharmsen@redhat.com> 1.1.0-10
- Added NSPR (devel) to "BuildRequires" and NSPR to "Requires".
- Bumped release number.

* Thu Mar 15 2007 Matthew Harmsen <mharmsen@redhat.com> 1.1.0-9
- Added specific "java" JVM to "BuildRequires".
- Bumped release number.

* Thu Mar 15 2007 Matthew Harmsen <mharmsen@redhat.com> 1.1.0-8
- Added "ant" to "BuildRequires".
- Bumped release number.

* Thu Mar 15 2007 Matthew Harmsen <mharmsen@redhat.com> 1.1.0-7
- Initial combined RPM and PKG spec file.

